@@ -1,15 +1,13 @@
 require 'date'
 
 require 'csv'
-if CSV.const_defined? :Reader
-  require 'fastercsv'
-end
+require 'json'
 
+require 'dbf/version'
 require 'dbf/schema'
 require 'dbf/record'
-require 'dbf/column/base'
-require 'dbf/column/dbase'
-require 'dbf/column/foxpro'
+require 'dbf/column_type'
+require 'dbf/column'
 require 'dbf/encodings'
 require 'dbf/header'
 require 'dbf/table'
