@@ -3,10 +3,10 @@ module DBF
     class Foxpro < Base
       FPT_HEADER_SIZE = 512
 
-      def build_memo(start_block) #nodoc
+      def build_memo(start_block) # nodoc
         @data.seek offset(start_block)
 
-        memo_type, memo_size, memo_string = @data.read(block_size).unpack("NNa*")
+        memo_type, memo_size, memo_string = @data.read(block_size).unpack('NNa*')
         return nil unless memo_type == 1 && memo_size > 0
 
         if memo_size > block_content_size
@@ -22,7 +22,7 @@ module DBF
 
       private
 
-      def block_size #nodoc
+      def block_size # nodoc
         @block_size ||= begin
           @data.rewind
           @data.read(FPT_HEADER_SIZE).unpack('x6n').first || 0
@@ -30,4 +30,4 @@ module DBF
       end
     end
   end
-end
\ No newline at end of file
+end
