@@ -9,7 +9,9 @@ module DBF
     # @memo [DBF::Memo]
     def initialize(data, columns, version, memo)
       @data = StringIO.new(data)
-      @columns, @version, @memo = columns, version, memo
+      @columns = columns
+      @version = version
+      @memo = memo
     end
 
     # Equality
@@ -24,7 +26,7 @@ module DBF
     #
     # @return [Array]
     def to_a
-      @columns.map {|column| attributes[column.name]}
+      @columns.map { |column| attributes[column.name] }
     end
 
     # Do all search parameters match?
@@ -32,15 +34,15 @@ module DBF
     # @param [Hash] options
     # @return [Boolean]
     def match?(options)
-      options.all? {|key, value| self[key] == value}
+      options.all? { |key, value| self[key] == value }
     end
 
     # Reads attributes by column name
     #
     # @param [String, Symbol] key
-    def [](key)
-      key = key.to_s
-      if attributes.has_key?(key)
+    def [](name)
+      key = name.to_s
+      if attributes.key?(key)
         attributes[key]
       elsif index = underscored_column_names.index(key)
         attributes[@columns[index].name]
@@ -51,7 +53,7 @@ module DBF
     #
     # @return [Hash]
     def attributes
-      @attributes ||= Hash[@columns.map {|column| [column.name, init_attribute(column)]}]
+      @attributes ||= Hash[attribute_map]
     end
 
     # Overrides standard Object.respond_to? to return true if a
@@ -60,17 +62,23 @@ module DBF
     # @param [String, Symbol] method
     # @return [Boolean]
     def respond_to?(method, *args)
-      if underscored_column_names.include?(method.to_s)
-        true
-      else
-        super
-      end
+      underscored_column_names.include?(method.to_s) || super
     end
 
     private
 
-    def method_missing(method, *args) #nodoc
-      if index = underscored_column_names.index(method.to_s)
+    def attribute_map # nodoc
+      @columns.map { |column| [column.name, init_attribute(column)] }
+    end
+
+    def file_offset(attribute_name) # nodoc
+      column = @columns.detect { |c| c.name == attribute_name.to_s }
+      index = @columns.index(column)
+      @columns[0, index + 1].compact.reduce(0) { |x, c| x += c.length }
+    end
+
+    def method_missing(method, *args) # nodoc
+      if (index = underscored_column_names.index(method.to_s))
         attributes[@columns[index].name]
       else
         super
@@ -78,15 +86,15 @@ module DBF
     end
 
     def underscored_column_names # nodoc
-      @underscored_column_names ||= @columns.map {|column| column.underscored_name}
+      @underscored_column_names ||= @columns.map(&:underscored_name)
     end
 
-    def init_attribute(column) #nodoc
-      value = column.memo? ? memo(column) : unpack_data(column)
+    def init_attribute(column) # nodoc
+      value = column.memo? ? memo(column) : get_data(column)
       column.type_cast(value)
     end
 
-    def memo(column) #nodoc
+    def memo(column) # nodoc
       if @memo
         @memo.get(memo_start_block(column))
       else
@@ -96,15 +104,16 @@ module DBF
       end
     end
 
-    def memo_start_block(column) #nodoc
-      format = 'V' if %w(30 31).include?(@version)
-      unpack_data(column, format).to_i
+    def memo_start_block(column) # nodoc
+      data = get_data(column)
+      if %w(30 31).include?(@version)
+        data = data.unpack('V').first
+      end
+      data.to_i
     end
 
-    def unpack_data(column, format=nil) #nodoc
-      format ||= "a#{column.length}"
-      @data.read(column.length).unpack(format).first
+    def get_data(column) # nodoc
+      @data.read(column.length)
     end
-
   end
 end
